@@ -45,10 +45,10 @@
 #' @references
 #'
 #' Goyal, Shuchi; Handcock, Mark S.; Jackson, Heide M.; Rendall, Michael S. and Yeung, Fiona C. (2023).
-#' \emph{A Practical Revealed Preference Model for Separating Preferences and Availability Effects in Marriage Formation}
+#' \emph{A Practical Revealed Preference Model for Separating Preferences and Availability Effects in Marriage Formation},
 #' \emph{Journal of the Royal Statistical Society}, A. \doi{10.1093/jrsssa/qnad031} 
 #'
-#' Dagsvik, John K. (2000) \emph{Aggregation in Matching Markets} \emph{International Economic Review}, Vol. 41, 27-57.
+#' Dagsvik, John K. (2000) \emph{Aggregation in Matching Markets} \emph{International Economic Review},, Vol. 41, 27-57.
 #' JSTOR: https://www.jstor.org/stable/2648822, \doi{10.1111/1468-2354.00054}
 #'
 #' Menzel, Konrad (2015).
@@ -128,7 +128,7 @@ rpmpopulationpmf <- function(object, N = 2000, num_women=NULL, num_men=NULL, pmf
       NumGammaM <- object$NumGammaM
       th_hat <- object$coefficients
 
-      pmf_target <- exp(augpmfnew(object$coefficients[1:object$NumBeta],
+      pmf_target <- exp(logpmfest(object$coefficients[1:object$NumBeta],
             GammaW=object$coefficients[object$NumBeta+(1:object$NumGammaW)],
             GammaM=object$coefficients[(object$NumBeta+object$NumGammaW)+(1:object$NumGammaM)],
             object$Sd, object$Xd, object$Zd,
