@@ -66,10 +66,10 @@
 #' @references
 #'
 #' Goyal, Shuchi; Handcock, Mark S.; Jackson, Heide M.; Rendall, Michael S. and Yeung, Fiona C. (2023).
-#' \emph{A Practical Revealed Preference Model for Separating Preferences and Availability Effects in Marriage Formation}
+#' \emph{A Practical Revealed Preference Model for Separating Preferences and Availability Effects in Marriage Formation},
 #' \emph{Journal of the Royal Statistical Society}, A. \doi{10.1093/jrsssa/qnad031} 
 #'
-#' Dagsvik, John K. (2000) \emph{Aggregation in Matching Markets} \emph{International Economic Review}, Vol. 41, 27-57.
+#' Dagsvik, John K. (2000) \emph{Aggregation in Matching Markets} \emph{International Economic Review},, Vol. 41, 27-57.
 #' JSTOR: https://www.jstor.org/stable/2648822, \doi{10.1111/1468-2354.00054}
 #'
 #' Menzel, Konrad (2015).
@@ -228,7 +228,7 @@ simulate.rpm <- function(object, nsim=1, seed = NULL, ..., N = NULL, num_women=N
         if(rescale){
           if(!bootstrap){
            # Note that this recomputes the Gammas based on beta, gw, gm, pmfW, pmfM
-            pmf_target <- exp(augpmfnew(beta=object$coefficients[1:object$NumBeta],
+            pmf_target <- exp(logpmfest(beta=object$coefficients[1:object$NumBeta],
                   GammaW=object$coefficients[object$NumBeta+(1:object$NumGammaW)],
                   GammaM=object$coefficients[(object$NumBeta+object$NumGammaW)+(1:object$NumGammaM)],
                   S=object$Sd, X=object$Xd, Z=object$Zd,
@@ -242,7 +242,7 @@ simulate.rpm <- function(object, nsim=1, seed = NULL, ..., N = NULL, num_women=N
         }else{
           if(!bootstrap){
            #pmf_target <- object$pmf_est
-            pmf_target <- exp(augpmfnew(beta=object$coefficients[1:object$NumBeta],
+            pmf_target <- exp(logpmfest(beta=object$coefficients[1:object$NumBeta],
                   GammaW=object$coefficients[object$NumBeta+(1:object$NumGammaW)],
                   GammaM=object$coefficients[(object$NumBeta+object$NumGammaW)+(1:object$NumGammaM)],
                   S=object$Sd, X=object$Xd, Z=object$Zd,
